@@ -84,7 +84,13 @@ class CommandResult(object):
         self._captured = value
 
 
-def command(command, capture=False, ignore=False):
+def command(command, capture=False, ignore=False, logger=None):
+    if logger is None:
+        log_output = False
+        logger = logging.getLogger('giza.command')
+    else:
+        log_output = True
+
     logger.debug("running '{0}'".format(command))
     if capture is False:
         tmp_out = DevNull()
@@ -116,6 +122,10 @@ def command(command, capture=False, ignore=False):
                         return_code=p.returncode)
     out.captured = capture
 
+    if log_output is True and capture is True:
+        logger.info(stdout)
+        logger.error(stderr)
+
     if out.succeeded is True or ignore is True:
         return out
     else:
