@@ -22,6 +22,8 @@ from giza.config.sphinx_local import SphinxLocalConfig
 from giza.config.manpage import ManpageConfig
 from giza.config.pdfs import PdfConfig
 from giza.config.intersphinx import IntersphinxConfig
+from giza.config.translate import TranslateConfig
+from giza.config.corpora import CorporaConfig
 from giza.serialization import ingest_yaml_list
 
 class SystemConfig(RecursiveConfigurationBase):
@@ -220,7 +222,11 @@ class SystemConfigData(RecursiveConfigurationBase):
         else:
             basename = os.path.splitext(fn)[0]
 
-        if fn.startswith('/'):
+        if os.path.exists(fn):
+            full_path = fn
+        elif os.path.exists(os.path.join(os.getcwd(), fn)):
+            full_path = os.path.join(os.getcwd(), fn)
+        elif fn.startswith('/'):
             full_path = os.path.join(self.conf.paths.projectroot, fn[1:])
         else:
             full_path = os.path.join(self.conf.paths.projectroot,
@@ -249,7 +255,9 @@ class SystemConfigData(RecursiveConfigurationBase):
                 'sphinx-local': SphinxLocalConfig,
                 'manpages': ManpageConfig,
                 'pdfs': PdfConfig,
-                'intersphinx': IntersphinxConfig
+                'intersphinx': IntersphinxConfig,
+                'translate': TranslateConfig,
+                'corpora': CorporaConfig
             }
 
             if basename in mapping:
