@@ -1,3 +1,17 @@
+# Copyright 2014 MongoDB, Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 from unittest import TestCase
 
 from giza.app import BuildApp
@@ -159,10 +173,10 @@ class TestBuildApp(TestCase):
         self.assertFalse(self.app.is_pool_type('threaded'))
 
     def test_is_pool_predicate_thead(self):
-        self.assertTrue(self.app.is_pool(ThreadPool()))
+        self.assertTrue(self.app.is_pool(ThreadPool(self.c)))
 
     def test_is_pool_predicate_process(self):
-        self.assertTrue(self.app.is_pool(ProcessPool()))
+        self.assertTrue(self.app.is_pool(ProcessPool(self.c)))
 
     def test_is_pool_predicate_serial(self):
         self.assertTrue(self.app.is_pool(SerialPool()))
